@@ -1,7 +1,7 @@
 from astrbot.core.utils.session_waiter import (
-    SessionWaiter,
     SessionController,
+    SessionWaiter,
     session_waiter,
 )
 
-__all__ = ["SessionWaiter", "SessionController", "session_waiter"]
+__all__ = ["SessionController", "SessionWaiter", "session_waiter"]
