@@ -1,12 +1,13 @@
-import mcp
-from dataclasses import dataclass
-from .run_context import ContextWrapper, TContext
 from typing import Generic
-from astrbot.core.provider.entities import LLMResponse
+
+import mcp
+
 from astrbot.core.agent.tool import FunctionTool
+from astrbot.core.provider.entities import LLMResponse
+
+from .run_context import ContextWrapper, TContext
 
 
-@dataclass
 class BaseAgentRunHooks(Generic[TContext]):
     async def on_agent_begin(self, run_context: ContextWrapper[TContext]): ...
     async def on_tool_start(
@@ -23,5 +24,7 @@ class BaseAgentRunHooks(Generic[TContext]):
         tool_result: mcp.types.CallToolResult | None,
     ): ...
     async def on_agent_done(
-        self, run_context: ContextWrapper[TContext], llm_response: LLMResponse
+        self,
+        run_context: ContextWrapper[TContext],
+        llm_response: LLMResponse,
     ): ...
