@@ -1,8 +1,7 @@
 from dataclasses import dataclass
 from typing import Any, Generic
-from typing_extensions import TypeVar
 
-from astrbot.core.platform.astr_message_event import AstrMessageEvent
+from typing_extensions import TypeVar
 
 TContext = TypeVar("TContext", default=Any)
 
@@ -12,7 +11,7 @@ class ContextWrapper(Generic[TContext]):
     """A context for running an agent, which can be used to pass additional data or state."""
 
     context: TContext
-    event: AstrMessageEvent
+    tool_call_timeout: int = 60  # Default tool call timeout in seconds
 
 
 NoContext = ContextWrapper[None]
