@@ -1,21 +1,24 @@
+import asyncio
 import os
 import re
-import asyncio
+
 import telegramify_markdown
+from telegram import ReactionTypeCustomEmoji, ReactionTypeEmoji
+from telegram.ext import ExtBot
+
+from astrbot import logger
 from astrbot.api.event import AstrMessageEvent, MessageChain
-from astrbot.api.platform import AstrBotMessage, PlatformMetadata, MessageType
 from astrbot.api.message_components import (
-    Plain,
-    Image,
-    Reply,
     At,
     File,
+    Image,
+    Plain,
     Record,
+    Reply,
 )
-from telegram.ext import ExtBot
-from astrbot.core.utils.io import download_file
-from astrbot import logger
+from astrbot.api.platform import AstrBotMessage, MessageType, PlatformMetadata
 from astrbot.core.utils.astrbot_path import get_astrbot_data_path
+from astrbot.core.utils.io import download_file
 
 
 class TelegramPlatformEvent(AstrMessageEvent):
@@ -67,7 +70,10 @@ class TelegramPlatformEvent(AstrMessageEvent):
 
     @classmethod
     async def send_with_client(
-        cls, client: ExtBot, message: MessageChain, user_name: str
+        cls,
+        client: ExtBot,
+        message: MessageChain,
+        user_name: str,
     ):
         image_path = None
 
@@ -103,14 +109,18 @@ class TelegramPlatformEvent(AstrMessageEvent):
                 for chunk in chunks:
                     try:
                         md_text = telegramify_markdown.markdownify(
-                            chunk, max_line_length=None, normalize_whitespace=False
+                            chunk,
+                            max_line_length=None,
+                            normalize_whitespace=False,
                         )
                         await client.send_message(
-                            text=md_text, parse_mode="MarkdownV2", **payload
+                            text=md_text,
+                            parse_mode="MarkdownV2",
+                            **payload,
                         )
                     except Exception as e:
                         logger.warning(
-                            f"MarkdownV2 send failed: {e}. Using plain text instead."
+                            f"MarkdownV2 send failed: {e}. Using plain text instead.",
                         )
                         await client.send_message(text=chunk, **payload)
             elif isinstance(i, Image):
@@ -135,6 +145,38 @@ class TelegramPlatformEvent(AstrMessageEvent):
             await self.send_with_client(self.client, message, self.get_sender_id())
         await super().send(message)
 
+    async def react(self, emoji: str | None, big: bool = False):
+        """给原消息添加 Telegram 反应：
+        - 普通 emoji：传入 '👍'、'😂' 等
+        - 自定义表情：传入其 custom_emoji_id（纯数字字符串）
+        - 取消本机器人的反应：传入 None 或空字符串
+        """
+        try:
+            # 解析 chat_id（去掉超级群的 "#<thread_id>" 片段）
+            if self.get_message_type() == MessageType.GROUP_MESSAGE:
+                chat_id = (self.message_obj.group_id or "").split("#")[0]
+            else:
+                chat_id = self.get_sender_id()
+
+            message_id = int(self.message_obj.message_id)
+
+            # 组装 reaction 参数（必须是 ReactionType 的列表）
+            if not emoji:  # 清空本 bot 的反应
+                reaction_param = []  # 空列表表示移除本 bot 的反应
+            elif emoji.isdigit():  # 自定义表情：传 custom_emoji_id
+                reaction_param = [ReactionTypeCustomEmoji(emoji)]
+            else:  # 普通 emoji
+                reaction_param = [ReactionTypeEmoji(emoji)]
+
+            await self.client.set_message_reaction(
+                chat_id=chat_id,
+                message_id=message_id,
+                reaction=reaction_param,  # 注意是列表
+                is_big=big,  # 可选：大动画
+            )
+        except Exception as e:
+            logger.error(f"[Telegram] 添加反应失败: {e}")
+
     async def send_streaming(self, generator, use_fallback: bool = False):
         message_thread_id = None
 
@@ -182,7 +224,9 @@ class TelegramPlatformEvent(AstrMessageEvent):
                             i.file = path
 
                         await self.client.send_document(
-                            document=i.file, filename=i.name, **payload
+                            document=i.file,
+                            filename=i.name,
+                            **payload,
                         )
                         continue
                     elif isinstance(i, Record):
@@ -229,7 +273,9 @@ class TelegramPlatformEvent(AstrMessageEvent):
             if delta and current_content != delta:
                 try:
                     markdown_text = telegramify_markdown.markdownify(
-                        delta, max_line_length=None, normalize_whitespace=False
+                        delta,
+                        max_line_length=None,
+                        normalize_whitespace=False,
                     )
                     await self.client.edit_message_text(
                         text=markdown_text,
@@ -240,7 +286,9 @@ class TelegramPlatformEvent(AstrMessageEvent):
                 except Exception as e:
                     logger.warning(f"Markdown转换失败，使用普通文本: {e!s}")
                     await self.client.edit_message_text(
-                        text=delta, chat_id=payload["chat_id"], message_id=message_id
+                        text=delta,
+                        chat_id=payload["chat_id"],
+                        message_id=message_id,
                     )
         except Exception as e:
             logger.warning(f"编辑消息失败(streaming): {e!s}")
