@@ -1,7 +1,4 @@
-# -*- coding: utf-8 -*-
-
-"""
-The MIT License (MIT)
+"""The MIT License (MIT)
 
 Copyright (c) 2014-2020 messense
 
@@ -28,15 +25,13 @@ from wechatpy.client.api.base import BaseWeChatAPI
 
 
 class WeChatKF(BaseWeChatAPI):
-    """
-    微信客服接口
+    """微信客服接口
 
     https://work.weixin.qq.com/api/doc/90000/90135/94670
     """
 
     def sync_msg(self, token, open_kfid, cursor="", limit=1000):
-        """
-        微信客户发送的消息、接待人员在企业微信回复的消息、发送消息接口发送失败事件（如被用户拒收）
+        """微信客户发送的消息、接待人员在企业微信回复的消息、发送消息接口发送失败事件（如被用户拒收）
         、客户点击菜单消息的回复消息，可以通过该接口获取具体的消息内容和事件。不支持读取通过发送消息接口发送的消息。
         支持的消息类型：文本、图片、语音、视频、文件、位置、链接、名片、小程序、事件。
 
@@ -57,8 +52,7 @@ class WeChatKF(BaseWeChatAPI):
         return self._post("kf/sync_msg", data=data)
 
     def get_service_state(self, open_kfid, external_userid):
-        """
-        获取会话状态
+        """获取会话状态
 
         ID	状态	说明
         0	未处理	新会话接入。可选择：1.直接用API自动回复消息。2.放进待接入池等待接待人员接待。3.指定接待人员进行接待
@@ -78,10 +72,13 @@ class WeChatKF(BaseWeChatAPI):
         return self._post("kf/service_state/get", data=data)
 
     def trans_service_state(
-        self, open_kfid, external_userid, service_state, servicer_userid=""
+        self,
+        open_kfid,
+        external_userid,
+        service_state,
+        servicer_userid="",
     ):
-        """
-        变更会话状态
+        """变更会话状态
 
         :param open_kfid: 客服帐号ID
         :param external_userid: 微信客户的external_userid
@@ -98,8 +95,7 @@ class WeChatKF(BaseWeChatAPI):
         return self._post("kf/service_state/trans", data=data)
 
     def get_servicer_list(self, open_kfid):
-        """
-        获取接待人员列表
+        """获取接待人员列表
 
         :param open_kfid: 客服帐号ID
         :return: 接口调用结果
@@ -110,8 +106,7 @@ class WeChatKF(BaseWeChatAPI):
         return self._get("kf/servicer/list", params=data)
 
     def add_servicer(self, open_kfid, userid_list):
-        """
-        添加接待人员
+        """添加接待人员
         添加指定客服帐号的接待人员。
 
         :param open_kfid: 客服帐号ID
@@ -128,8 +123,7 @@ class WeChatKF(BaseWeChatAPI):
         return self._post("kf/servicer/add", data=data)
 
     def del_servicer(self, open_kfid, userid_list):
-        """
-        删除接待人员
+        """删除接待人员
         从客服帐号删除接待人员
 
         :param open_kfid: 客服帐号ID
@@ -146,8 +140,7 @@ class WeChatKF(BaseWeChatAPI):
         return self._post("kf/servicer/del", data=data)
 
     def batchget_customer(self, external_userid_list):
-        """
-        客户基本信息获取
+        """客户基本信息获取
 
         :param external_userid_list: external_userid列表
         :return: 接口调用结果
@@ -161,16 +154,14 @@ class WeChatKF(BaseWeChatAPI):
         return self._post("kf/customer/batchget", data=data)
 
     def get_account_list(self):
-        """
-        获取客服帐号列表
+        """获取客服帐号列表
 
         :return: 接口调用结果
         """
         return self._get("kf/account/list")
 
     def add_contact_way(self, open_kfid, scene):
-        """
-        获取客服帐号链接
+        """获取客服帐号链接
 
         :param open_kfid: 	客服帐号ID
         :param scene: 场景值，字符串类型，由开发者自定义。不多于32字节;字符串取值范围(正则表达式)：[0-9a-zA-Z_-]*
@@ -180,18 +171,21 @@ class WeChatKF(BaseWeChatAPI):
         return self._post("kf/add_contact_way", data=data)
 
     def get_upgrade_service_config(self):
-        """
-        获取配置的专员与客户群
+        """获取配置的专员与客户群
 
         :return: 接口调用结果
         """
         return self._get("kf/customer/get_upgrade_service_config")
 
     def upgrade_service(
-        self, open_kfid, external_userid, service_type, member=None, groupchat=None
+        self,
+        open_kfid,
+        external_userid,
+        service_type,
+        member=None,
+        groupchat=None,
     ):
-        """
-        为客户升级为专员或客户群服务
+        """为客户升级为专员或客户群服务
 
         :param open_kfid: 	客服帐号ID
         :param external_userid: 微信客户的external_userid
@@ -200,7 +194,6 @@ class WeChatKF(BaseWeChatAPI):
         :param groupchat: 推荐的客户群，type等于2时有效
         :return: 接口调用结果
         """
-
         data = {
             "open_kfid": open_kfid,
             "external_userid": external_userid,
@@ -213,20 +206,17 @@ class WeChatKF(BaseWeChatAPI):
         return self._post("kf/customer/upgrade_service", data=data)
 
     def cancel_upgrade_service(self, open_kfid, external_userid):
-        """
-        为客户取消推荐
+        """为客户取消推荐
 
         :param open_kfid: 	客服帐号ID
         :param external_userid: 微信客户的external_userid
         :return: 接口调用结果
         """
-
         data = {"open_kfid": open_kfid, "external_userid": external_userid}
         return self._post("kf/customer/cancel_upgrade_service", data=data)
 
     def send_msg_on_event(self, code, msgtype, msg_content, msgid=None):
-        """
-        当特定的事件回调消息包含code字段，可以此code为凭证，调用该接口给用户发送相应事件场景下的消息，如客服欢迎语。
+        """当特定的事件回调消息包含code字段，可以此code为凭证，调用该接口给用户发送相应事件场景下的消息，如客服欢迎语。
         支持发送消息类型：文本、菜单消息。
 
         :param code: 事件响应消息对应的code。通过事件回调下发，仅可使用一次。
@@ -236,7 +226,6 @@ class WeChatKF(BaseWeChatAPI):
                       字符串取值范围(正则表达式)：[0-9a-zA-Z_-]*
         :return: 接口调用结果
         """
-
         data = {"code": code, "msgtype": msgtype}
         if msgid:
             data["msgid"] = msgid
@@ -244,8 +233,7 @@ class WeChatKF(BaseWeChatAPI):
         return self._post("kf/send_msg_on_event", data=data)
 
     def get_corp_statistic(self, start_time, end_time, open_kfid=None):
-        """
-        获取「客户数据统计」企业汇总数据
+        """获取「客户数据统计」企业汇总数据
 
         :param start_time: 开始时间
         :param end_time: 结束时间
@@ -256,10 +244,13 @@ class WeChatKF(BaseWeChatAPI):
         return self._post("kf/get_corp_statistic", data=data)
 
     def get_servicer_statistic(
-        self, start_time, end_time, open_kfid=None, servicer_userid=None
+        self,
+        start_time,
+        end_time,
+        open_kfid=None,
+        servicer_userid=None,
     ):
-        """
-        获取「客户数据统计」接待人员明细数据
+        """获取「客户数据统计」接待人员明细数据
 
         :param start_time: 开始时间
         :param end_time: 结束时间
@@ -276,8 +267,7 @@ class WeChatKF(BaseWeChatAPI):
         return self._post("kf/get_servicer_statistic", data=data)
 
     def account_update(self, open_kfid, name, media_id):
-        """
-        修改客服账号
+        """修改客服账号
 
         :param open_kfid: 客服帐号ID
         :param name: 客服名称
