@@ -1,21 +1,20 @@
 import asyncio
 import traceback
-from typing import List
 
 from astrbot.core import logger, sp
 from astrbot.core.astrbot_config_mgr import AstrBotConfigManager
 from astrbot.core.db import BaseDatabase
 
+from ..persona_mgr import PersonaManager
 from .entities import ProviderType
 from .provider import (
+    EmbeddingProvider,
     Provider,
+    RerankProvider,
     STTProvider,
     TTSProvider,
-    EmbeddingProvider,
-    RerankProvider,
 )
 from .register import llm_tools, provider_cls_map
-from ..persona_mgr import PersonaManager
 
 
 class ProviderManager:
@@ -28,7 +27,7 @@ class ProviderManager:
         self.persona_mgr = persona_mgr
         self.acm = acm
         config = acm.confs["default"]
-        self.providers_config: List = config["provider"]
+        self.providers_config: list = config["provider"]
         self.provider_settings: dict = config["provider_settings"]
         self.provider_stt_settings: dict = config.get("provider_stt_settings", {})
         self.provider_tts_settings: dict = config.get("provider_tts_settings", {})
@@ -36,15 +35,15 @@ class ProviderManager:
         # 人格相关属性，v4.0.0 版本后被废弃，推荐使用 PersonaManager
         self.default_persona_name = persona_mgr.default_persona
 
-        self.provider_insts: List[Provider] = []
+        self.provider_insts: list[Provider] = []
         """加载的 Provider 的实例"""
-        self.stt_provider_insts: List[STTProvider] = []
+        self.stt_provider_insts: list[STTProvider] = []
         """加载的 Speech To Text Provider 的实例"""
-        self.tts_provider_insts: List[TTSProvider] = []
+        self.tts_provider_insts: list[TTSProvider] = []
         """加载的 Text To Speech Provider 的实例"""
-        self.embedding_provider_insts: List[EmbeddingProvider] = []
+        self.embedding_provider_insts: list[EmbeddingProvider] = []
         """加载的 Embedding Provider 的实例"""
-        self.rerank_provider_insts: List[RerankProvider] = []
+        self.rerank_provider_insts: list[RerankProvider] = []
         """加载的 Rerank Provider 的实例"""
         self.inst_map: dict[
             str,
@@ -77,7 +76,10 @@ class ProviderManager:
         return self.persona_mgr.selected_default_persona_v3
 
     async def set_provider(
-        self, provider_id: str, provider_type: ProviderType, umo: str | None = None
+        self,
+        provider_id: str,
+        provider_type: ProviderType,
+        umo: str | None = None,
     ):
         """设置提供商。
 
@@ -87,6 +89,7 @@ class ProviderManager:
             umo (str, optional): 用户会话 ID，用于提供商会话隔离。
 
         Version 4.0.0: 这个版本下已经默认隔离提供商
+
         """
         if provider_id not in self.inst_map:
             raise ValueError(f"提供商 {provider_id} 不存在，无法设置。")
@@ -101,17 +104,20 @@ class ProviderManager:
 
         prov = self.inst_map[provider_id]
         if provider_type == ProviderType.TEXT_TO_SPEECH and isinstance(
-            prov, TTSProvider
+            prov,
+            TTSProvider,
         ):
             self.curr_tts_provider_inst = prov
             sp.put("curr_provider_tts", provider_id, scope="global", scope_id="global")
         elif provider_type == ProviderType.SPEECH_TO_TEXT and isinstance(
-            prov, STTProvider
+            prov,
+            STTProvider,
         ):
             self.curr_stt_provider_inst = prov
             sp.put("curr_provider_stt", provider_id, scope="global", scope_id="global")
         elif provider_type == ProviderType.CHAT_COMPLETION and isinstance(
-            prov, Provider
+            prov,
+            Provider,
         ):
             self.curr_provider_inst = prov
             sp.put("curr_provider", provider_id, scope="global", scope_id="global")
@@ -121,7 +127,9 @@ class ProviderManager:
         return self.inst_map.get(provider_id)
 
     def get_using_provider(
-        self, provider_type: ProviderType, umo=None
+        self,
+        provider_type: ProviderType,
+        umo=None,
     ) -> Provider | STTProvider | TTSProvider | None:
         """获取正在使用的提供商实例。
 
@@ -131,6 +139,7 @@ class ProviderManager:
 
         Returns:
             Provider: 正在使用的提供商实例。
+
         """
         provider = None
         if umo:
@@ -175,7 +184,11 @@ class ProviderManager:
     async def initialize(self):
         # 逐个初始化提供商
         for provider_config in self.providers_config:
-            await self.load_provider(provider_config)
+            try:
+                await self.load_provider(provider_config)
+            except Exception as e:
+                logger.error(traceback.format_exc())
+                logger.error(e)
 
         # 设置默认提供商
         selected_provider_id = sp.get(
@@ -216,7 +229,7 @@ class ProviderManager:
             return
 
         logger.info(
-            f"载入 {provider_config['type']}({provider_config['id']}) 服务提供商 ..."
+            f"载入 {provider_config['type']}({provider_config['id']}) 服务提供商 ...",
         )
 
         # 动态导入
@@ -234,6 +247,8 @@ class ProviderManager:
                     )
                 case "dify":
                     from .sources.dify_source import ProviderDify as ProviderDify
+                case "coze":
+                    from .sources.coze_source import ProviderCoze as ProviderCoze
                 case "dashscope":
                     from .sources.dashscope_source import (
                         ProviderDashscope as ProviderDashscope,
@@ -254,6 +269,10 @@ class ProviderManager:
                     from .sources.whisper_selfhosted_source import (
                         ProviderOpenAIWhisperSelfHost as ProviderOpenAIWhisperSelfHost,
                     )
+                case "xinference_stt":
+                    from .sources.xinference_stt_provider import (
+                        ProviderXinferenceSTT as ProviderXinferenceSTT,
+                    )
                 case "openai_tts_api":
                     from .sources.openai_tts_api_source import (
                         ProviderOpenAITTSAPI as ProviderOpenAITTSAPI,
@@ -306,20 +325,24 @@ class ProviderManager:
                     from .sources.vllm_rerank_source import (
                         VLLMRerankProvider as VLLMRerankProvider,
                     )
+                case "xinference_rerank":
+                    from .sources.xinference_rerank_source import (
+                        XinferenceRerankProvider as XinferenceRerankProvider,
+                    )
         except (ImportError, ModuleNotFoundError) as e:
             logger.critical(
-                f"加载 {provider_config['type']}({provider_config['id']}) 提供商适配器失败：{e}。可能是因为有未安装的依赖。"
+                f"加载 {provider_config['type']}({provider_config['id']}) 提供商适配器失败：{e}。可能是因为有未安装的依赖。",
             )
             return
         except Exception as e:
             logger.critical(
-                f"加载 {provider_config['type']}({provider_config['id']}) 提供商适配器失败：{e}。未知原因"
+                f"加载 {provider_config['type']}({provider_config['id']}) 提供商适配器失败：{e}。未知原因",
             )
             return
 
         if provider_config["type"] not in provider_cls_map:
             logger.error(
-                f"未找到适用于 {provider_config['type']}({provider_config['id']}) 的提供商适配器，请检查是否已经安装或者名称填写错误。已跳过。"
+                f"未找到适用于 {provider_config['type']}({provider_config['id']}) 的提供商适配器，请检查是否已经安装或者名称填写错误。已跳过。",
             )
             return
 
@@ -345,7 +368,7 @@ class ProviderManager:
                 ):
                     self.curr_stt_provider_inst = inst
                     logger.info(
-                        f"已选择 {provider_config['type']}({provider_config['id']}) 作为当前语音转文本提供商适配器。"
+                        f"已选择 {provider_config['type']}({provider_config['id']}) 作为当前语音转文本提供商适配器。",
                     )
                 if not self.curr_stt_provider_inst:
                     self.curr_stt_provider_inst = inst
@@ -361,7 +384,7 @@ class ProviderManager:
                 if self.provider_settings.get("provider_id") == provider_config["id"]:
                     self.curr_tts_provider_inst = inst
                     logger.info(
-                        f"已选择 {provider_config['type']}({provider_config['id']}) 作为当前文本转语音提供商适配器。"
+                        f"已选择 {provider_config['type']}({provider_config['id']}) 作为当前文本转语音提供商适配器。",
                     )
                 if not self.curr_tts_provider_inst:
                     self.curr_tts_provider_inst = inst
@@ -384,7 +407,7 @@ class ProviderManager:
                 ):
                     self.curr_provider_inst = inst
                     logger.info(
-                        f"已选择 {provider_config['type']}({provider_config['id']}) 作为当前提供商适配器。"
+                        f"已选择 {provider_config['type']}({provider_config['id']}) 作为当前提供商适配器。",
                     )
                 if not self.curr_provider_inst:
                     self.curr_provider_inst = inst
@@ -402,9 +425,11 @@ class ProviderManager:
 
             self.inst_map[provider_config["id"]] = inst
         except Exception as e:
-            logger.error(traceback.format_exc())
             logger.error(
-                f"实例化 {provider_config['type']}({provider_config['id']}) 提供商适配器失败：{e}"
+                f"实例化 {provider_config['type']}({provider_config['id']}) 提供商适配器失败：{e}",
+            )
+            raise Exception(
+                f"实例化 {provider_config['type']}({provider_config['id']}) 提供商适配器失败：{e}",
             )
 
     async def reload(self, provider_config: dict):
@@ -424,7 +449,7 @@ class ProviderManager:
         elif self.curr_provider_inst is None and len(self.provider_insts) > 0:
             self.curr_provider_inst = self.provider_insts[0]
             logger.info(
-                f"自动选择 {self.curr_provider_inst.meta().id} 作为当前提供商适配器。"
+                f"自动选择 {self.curr_provider_inst.meta().id} 作为当前提供商适配器。",
             )
 
         if len(self.stt_provider_insts) == 0:
@@ -432,7 +457,7 @@ class ProviderManager:
         elif self.curr_stt_provider_inst is None and len(self.stt_provider_insts) > 0:
             self.curr_stt_provider_inst = self.stt_provider_insts[0]
             logger.info(
-                f"自动选择 {self.curr_stt_provider_inst.meta().id} 作为当前语音转文本提供商适配器。"
+                f"自动选择 {self.curr_stt_provider_inst.meta().id} 作为当前语音转文本提供商适配器。",
             )
 
         if len(self.tts_provider_insts) == 0:
@@ -440,7 +465,7 @@ class ProviderManager:
         elif self.curr_tts_provider_inst is None and len(self.tts_provider_insts) > 0:
             self.curr_tts_provider_inst = self.tts_provider_insts[0]
             logger.info(
-                f"自动选择 {self.curr_tts_provider_inst.meta().id} 作为当前文本转语音提供商适配器。"
+                f"自动选择 {self.curr_tts_provider_inst.meta().id} 作为当前文本转语音提供商适配器。",
             )
 
     def get_insts(self):
@@ -449,7 +474,7 @@ class ProviderManager:
     async def terminate_provider(self, provider_id: str):
         if provider_id in self.inst_map:
             logger.info(
-                f"终止 {provider_id} 提供商适配器({len(self.provider_insts)}, {len(self.stt_provider_insts)}, {len(self.tts_provider_insts)}) ..."
+                f"终止 {provider_id} 提供商适配器({len(self.provider_insts)}, {len(self.stt_provider_insts)}, {len(self.tts_provider_insts)}) ...",
             )
 
             if self.inst_map[provider_id] in self.provider_insts:
@@ -476,7 +501,7 @@ class ProviderManager:
                 await self.inst_map[provider_id].terminate()  # type: ignore
 
             logger.info(
-                f"{provider_id} 提供商适配器已终止({len(self.provider_insts)}, {len(self.stt_provider_insts)}, {len(self.tts_provider_insts)})"
+                f"{provider_id} 提供商适配器已终止({len(self.provider_insts)}, {len(self.stt_provider_insts)}, {len(self.tts_provider_insts)})",
             )
             del self.inst_map[provider_id]
 
