@@ -1,17 +1,19 @@
-import traceback
-import psutil
-import time
 import threading
+import time
+import traceback
+
 import aiohttp
-from .route import Route, Response, RouteContext
-from astrbot.core import logger
+import psutil
 from quart import request
+
+from astrbot.core import DEMO_MODE, logger
+from astrbot.core.config import VERSION
 from astrbot.core.core_lifecycle import AstrBotCoreLifecycle
 from astrbot.core.db import BaseDatabase
-from astrbot.core.config import VERSION
-from astrbot.core.utils.io import get_dashboard_version
-from astrbot.core import DEMO_MODE
 from astrbot.core.db.migration.helper import check_migration_needed_v4
+from astrbot.core.utils.io import get_dashboard_version
+
+from .route import Response, Route, RouteContext
 
 
 class StatRoute(Route):
@@ -70,7 +72,7 @@ class StatRoute(Route):
                     "dashboard_version": await get_dashboard_version(),
                     "change_pwd_hint": self.is_default_cred(),
                     "need_migration": need_migration,
-                }
+                },
             )
             .__dict__
         )
@@ -116,17 +118,17 @@ class StatRoute(Route):
 
             # 计算运行时长组件
             running_time = self._get_running_time_components(
-                int(time.time()) - self.core_lifecycle.start_time
+                int(time.time()) - self.core_lifecycle.start_time,
             )
 
             stat_dict.update(
                 {
                     "platform": self.db_helper.get_grouped_base_stats(
-                        offset_sec
+                        offset_sec,
                     ).platform,
                     "message_count": self.db_helper.get_total_message_count() or 0,
                     "platform_count": len(
-                        self.core_lifecycle.platform_manager.get_insts()
+                        self.core_lifecycle.platform_manager.get_insts(),
                     ),
                     "plugin_count": len(plugins),
                     "plugins": plugin_info,
@@ -139,7 +141,7 @@ class StatRoute(Route):
                     "cpu_percent": round(cpu_percent, 1),
                     "thread_count": thread_count,
                     "start_time": self.core_lifecycle.start_time,
-                }
+                },
             )
 
             return Response().ok(stat_dict).__dict__
@@ -148,9 +150,7 @@ class StatRoute(Route):
             return Response().error(e.__str__()).__dict__
 
     async def test_ghproxy_connection(self):
-        """
-        测试 GitHub 代理连接是否可用。
-        """
+        """测试 GitHub 代理连接是否可用。"""
         try:
             data = await request.get_json()
             proxy_url: str = data.get("proxy_url")
@@ -163,23 +163,23 @@ class StatRoute(Route):
             test_url = f"{proxy_url}/https://github.com/AstrBotDevs/AstrBot/raw/refs/heads/master/.python-version"
             start_time = time.time()
 
-            async with aiohttp.ClientSession() as session:
-                async with session.get(
-                    test_url, timeout=aiohttp.ClientTimeout(total=10)
-                ) as response:
-                    if response.status == 200:
-                        end_time = time.time()
-                        _ = await response.text()
-                        ret = {
-                            "latency": round((end_time - start_time) * 1000, 2),
-                        }
-                        return Response().ok(data=ret).__dict__
-                    else:
-                        return (
-                            Response()
-                            .error(f"Failed. Status code: {response.status}")
-                            .__dict__
-                        )
+            async with (
+                aiohttp.ClientSession() as session,
+                session.get(
+                    test_url,
+                    timeout=aiohttp.ClientTimeout(total=10),
+                ) as response,
+            ):
+                if response.status == 200:
+                    end_time = time.time()
+                    _ = await response.text()
+                    ret = {
+                        "latency": round((end_time - start_time) * 1000, 2),
+                    }
+                    return Response().ok(data=ret).__dict__
+                return (
+                    Response().error(f"Failed. Status code: {response.status}").__dict__
+                )
         except Exception as e:
             logger.error(traceback.format_exc())
-            return Response().error(f"Error: {str(e)}").__dict__
+            return Response().error(f"Error: {e!s}").__dict__
